@@ -3,6 +3,7 @@
 
 from __future__ import with_statement
 import re
+import codecs
 import os.path
 import datetime
 import subprocess
@@ -18,7 +19,7 @@ class SqlplusCommando(object):
     def __init__(self, configuration=None,
                  hostname=None, database=None,
                  username=None, password=None,
-                 cast=True):
+                 encoding=None, cast=True):
         if hostname and database and username and password:
             self.hostname = hostname
             self.database = database
@@ -31,6 +32,7 @@ class SqlplusCommando(object):
             self.password = configuration['password']
         else:
             raise SqlplusException('Missing database configuration')
+        self.encoding = encoding
         self.cast = cast
 
     def run_query(self, query, parameters={}, cast=True, check_errors=True):
@@ -42,7 +44,10 @@ class SqlplusCommando(object):
                                    stdin=subprocess.PIPE,
                                    stdout=subprocess.PIPE,
                                    stderr=subprocess.PIPE)
-        session.stdin.write(query)
+        if self.encoding:
+            session.stdin.write(query.encode(self.encoding))
+        else:
+            session.stdin.write(query)
         output, _ = session.communicate(self.EXIT_COMMAND)
         code = session.returncode
         if code != 0:
@@ -55,8 +60,14 @@ class SqlplusCommando(object):
     def run_script(self, script, cast=True, check_errors=True):
         if not os.path.isfile(script):
             raise SqlplusException("Script '%s' was not found" % script)
-        with open(script) as stream:
-            source = stream.read()
+        if self.encoding:
+            # read enforcing encoding
+            with codecs.open(script, mode='rb', encoding=self.encoding, errors='strict') as stream:
+                source = stream.read()
+        else:
+            # read without encoding
+            with open(script) as stream:
+                source = stream.read()
         return self.run_query(query=source, cast=cast, check_errors=check_errors)
 
     def _get_connection_url(self):
